==> php81-nextcloud-30.0.2.tgz: share/nextcloud/apps/serverinfo/l10n/tr.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "İşlemci bilgileri alınamadı",
    "Load average: {cpu} (last minute)" : "Ortalama yük: {cpu} (son bir dakika)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Toplam: {memTotalBytes}/Güncel kullanım: {memUsageBytes}",
    "RAM info not available" : "RAM bilgileri alınamadı",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Toplam: {swapTotalBytes}/Güncel kullanım: {swapUsageBytes}",
    "SWAP info not available" : "SWAP bilgileri alınamadı",
    "Copied!" : "Kopyalandı!",
    "Not supported!" : "Desteklenmiyor!",
    "Press ⌘-C to copy." : "Kopyalamak için ⌘-C tuşlarına basın.",
    "Press Ctrl-C to copy." : "Kopyalamak için Ctrl-C tuşlarına basın.",
    "System" : "Sistem",
    "Monitoring" : "İzleniyor",
    "Monitoring app with useful server information" : "Yararlı sunucu bilgileri sunan izleme uygulaması",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "İşlemci yükü, bellek ve disk kullanımı, kullanıcı sayısı gibi sunucu hakkında çeşitli bilgiler sağlar. ",
    "Operating System:" : "İşletim sistemi:",
    "CPU:" : "İşlemci",
    "Unknown Processor" : "İşlemci bilinmiyor",
    "Memory:" : "Bellek:",
    "Server time:" : "Sunucu zamanı:",
    "Uptime:" : "Çalışma süresi:",
    "Temperature" : "Sıcaklık",
    "Load" : "Yük",
    "Memory" : "Bellek",
    "Disk" : "Disk",
    "Mount:" : "Takılı:",
    "Filesystem:" : "Dosya sistemi:",
    "Size:" : "Boyut:",
    "Available:" : "Kullanılabilir:",
    "Used:" : "Kullanılan:",
    "Files:" : "Dosyalar:",
    "Storages:" : "Depolama birimleri:",
    "Free Space:" : "Boş alan:",
    "Network" : "Ağ",
    "Hostname:" : "Sunucu adı:",
    "Gateway:" : "Ağ geçidi:",
    "Status:" : "Durum:",
    "Speed:" : "Hız:",
    "Duplex:" : "Çift taraflı:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Etkin kullanıcılar",
    "Last hour" : "Son 1 saat",
    "%s%% of all users" : "Tüm kullanıcıların %%%s",
    "Last 24 Hours" : "Son 24 saat",
    "Last 7 Days" : "Son 7 gün",
    "Last 30 Days" : "Son 30 gün",
    "Shares" : "Paylaşımlar",
    "Users:" : "Kullanıcılar:",
    "Groups:" : "Gruplar:",
    "Links:" : "Bağlantılar:",
    "Emails:" : "E-postalar:",
    "Federated sent:" : "Birleşik gönderilen:",
    "Federated received:" : "Birleşik alınan:",
    "Talk conversations:" : "Konuş görüşmeleri:",
    "PHP" : "PHP",
    "Version:" : "Sürüm:",
    "Memory limit:" : "Bellek sınırı:",
    "Max execution time:" : "En uzun çalışma süresi:",
    "Upload max size:" : "En büyük yükleme boyutu:",
    "OPcache Revalidate Frequency:" : "OPcache yeniden doğrulama sıklığı:",
    "Extensions:" : "Eklentiler:",
    "Unable to list extensions" : "Eklentiler listelenemedi",
    "Show phpinfo" : "PHP bilgilerini görüntüle",
    "Database" : "Veri tabanı",
    "Type:" : "Tür:",
    "External monitoring tool" : "Dış izleme aracı",
    "Use this end point to connect an external monitoring tool:" : "Bir dış izleme aracına bağlanmak için bu uç noktayı kullanın:",
    "Copy" : "Kopyala",
    "Output in JSON" : "JSON çıktısı",
    "Skip apps section (including apps section will send an external request to the app store)" : "Uygulamalar bölümü atlansın (uygulamalar bölümünün katılması, uygulama mağazasına bir dış istek gönderir)",
    "Skip server update" : "Sunucu güncellemesini atla",
    "To use an access token, please generate one then set it using the following command:" : "Erişim kodunu kullanmak için yeni bir kod oluşturup şu komutu yürüterek ayarlayın:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Ardından yukarıdaki adresi sorgularken kodu \"NC-Token\" üst bilgisi ile gönderin.",
    "DNS:" : "DNS:",
    "Total users:" : "Kullanıcı sayısı:",
    "24 hours:" : "24 saat:",
    "1 hour:" : "1 saat:",
    "5 mins:" : "5 dakika:"
},
"nplurals=2; plural=(n > 1);");

==> php81-nextcloud-30.0.5.tgz: share/nextcloud/apps/serverinfo/l10n/tr.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "İşlemci bilgileri alınamadı",
    "CPU Usage:" : "İşlemci kullanımı:",
    "Load average: {percentage} % ({load}) last minute" : "Ortalama yük: % {percentage} ({load}) son 1 dakika",
    "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes" : "% {lastMinutePercentage} ({lastMinute}) son 1 dakika\n% {last5MinutesPercentage} ({last5Minutes}) son 5 dakika\n% {last15MinutesPercentage} ({last15Minutes}) son 15 dakika",
    "RAM Usage:" : "Bellek kullanımı:",
    "SWAP Usage:" : "Takas dosyası kullanımı:",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Toplam: {memTotalBytes}/Güncel kullanım: {memUsageBytes}",
    "RAM info not available" : "RAM bilgileri alınamadı",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Toplam: {swapTotalBytes}/Güncel kullanım: {swapUsageBytes}",
    "SWAP info not available" : "SWAP bilgileri alınamadı",
    "Copied!" : "Kopyalandı!",
    "Not supported!" : "Desteklenmiyor!",
    "Press ⌘-C to copy." : "Kopyalamak için ⌘-C tuşlarına basın.",
    "Press Ctrl-C to copy." : "Kopyalamak için Ctrl-C tuşlarına basın.",
    "System" : "Sistem",
    "Monitoring" : "İzleniyor",
    "Monitoring app with useful server information" : "Yararlı sunucu bilgileri sunan izleme uygulaması",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "İşlemci yükü, bellek ve disk kullanımı, kullanıcı sayısı gibi sunucu hakkında çeşitli bilgiler sağlar. ",
    "Operating System:" : "İşletim sistemi:",
    "CPU:" : "İşlemci",
    "Unknown Processor" : "İşlemci bilinmiyor",
    "Memory:" : "Bellek:",
    "Server time:" : "Sunucu zamanı:",
    "Uptime:" : "Çalışma süresi:",
    "Temperature" : "Sıcaklık",
    "Load" : "Yük",
    "Memory" : "Bellek",
    "Disk" : "Disk",
    "Mount:" : "Takılı:",
    "Filesystem:" : "Dosya sistemi:",
    "Size:" : "Boyut:",
    "Available:" : "Kullanılabilir:",
    "Used:" : "Kullanılan:",
    "Files:" : "Dosyalar:",
    "Storages:" : "Depolama birimleri:",
    "Free Space:" : "Boş alan:",
    "Network" : "Ağ",
    "Hostname:" : "Sunucu adı:",
    "Gateway:" : "Ağ geçidi:",
    "Status:" : "Durum:",
    "Speed:" : "Hız:",
    "Duplex:" : "Çift taraflı:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Etkin kullanıcılar",
    "Last hour" : "Son 1 saat",
    "%s%% of all users" : "Tüm kullanıcıların %%%s",
    "Last 24 Hours" : "Son 24 saat",
    "Last 7 Days" : "Son 7 gün",
    "Last 30 Days" : "Son 30 gün",
    "Shares" : "Paylaşımlar",
    "Users:" : "Kullanıcılar:",
    "Groups:" : "Gruplar:",
    "Links:" : "Bağlantılar:",
    "Emails:" : "E-postalar:",
    "Federated sent:" : "Birleşik gönderilen:",
    "Federated received:" : "Birleşik alınan:",
    "Talk conversations:" : "Konuş görüşmeleri:",
    "PHP" : "PHP",
    "Version:" : "Sürüm:",
    "Memory limit:" : "Bellek sınırı:",
    "Max execution time:" : "En uzun çalışma süresi:",
    "Upload max size:" : "En büyük yükleme boyutu:",
    "OPcache Revalidate Frequency:" : "OPcache yeniden doğrulama sıklığı:",
    "Extensions:" : "Eklentiler:",
    "Unable to list extensions" : "Eklentiler listelenemedi",
    "Show phpinfo" : "PHP bilgilerini görüntüle",
    "Database" : "Veri tabanı",
    "Type:" : "Tür:",
    "External monitoring tool" : "Dış izleme aracı",
    "Use this end point to connect an external monitoring tool:" : "Bir dış izleme aracına bağlanmak için bu uç noktayı kullanın:",
    "Copy" : "Kopyala",
    "Output in JSON" : "JSON çıktısı",
    "Skip apps section (including apps section will send an external request to the app store)" : "Uygulamalar bölümü atlansın (uygulamalar bölümünün katılması, uygulama mağazasına bir dış istek gönderir)",
    "Skip server update" : "Sunucu güncellemesini atla",
    "To use an access token, please generate one then set it using the following command:" : "Erişim kodunu kullanmak için yeni bir kod oluşturup şu komutu yürüterek ayarlayın:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Ardından yukarıdaki adresi sorgularken kodu \"NC-Token\" üst bilgisi ile gönderin.",
    "Load average: {cpu} (last minute)" : "Ortalama yük: {cpu} (son bir dakika)",
    "DNS:" : "DNS:",
    "Total users:" : "Kullanıcı sayısı:",
    "24 hours:" : "24 saat:",
    "1 hour:" : "1 saat:",
    "5 mins:" : "5 dakika:"
},
"nplurals=2; plural=(n > 1);");
